import { feature } from 'topojson';

import { 
  select, 
  json, 
  tsv, 
  geoPath, 
  geoEqualEarth, 
  zoom,
	event
	} from 'd3';

const svg = select('svg');
const projection = geoEqualEarth();
const pathGenerator = geoPath().projection(projection);
const g = svg.append('g');

g.append('path')
	.attr('d', pathGenerator({type: 'Sphere'}))
	.attr('class', 'sphere');

svg.call(zoom().on('zoom', () => {
		g.attr('transform', event.transform);
	}));


Promise.all([
	tsv('https://unpkg.com/world-atlas@1.1.4/world/50m.tsv'),
	json('https://unpkg.com/world-atlas@1/world/50m.json')
]).then(([tsvData, topoJsonData]) => {

  const countryName = tsvData.reduce((acumulator, d) => {
  	acumulator[d.iso_n3] = d.name;
    return acumulator;
  }, {});
  
/*
	um outro jeito de mapear os dados
  const countryName = {};
  tsvData.forEach(d => {
  	countryName[d.iso_n3] = d.name;	
  });

*/
  
  
  const countries = feature(topoJsonData, topoJsonData.objects.countries);
  
  g.selectAll('path')
    .data(countries.features)
    .enter()
    .append('path')
      .attr('class', 'countries')
      .attr('d', pathGenerator)
  	.append('title')
  		.text(d => countryName[d.id]);
  
});










